@@ -1,3 +1,3 @@
 from DeepMIMO.generator import generate_data
 from DeepMIMO.params import default_params
-from DeepMIMO.construct_deepmimo import ant_indices
\ No newline at end of file
+from DeepMIMO.construct_deepmimo import ant_indices, array_response
\ No newline at end of file
